(elapsed-signal? description)Timeout for synchronous health checks in milliseconds. Used by the health check "driver" to abort runaway checks. Should also be used by the function performing actual checks where appropriate.
Timeout for synchronous health checks in milliseconds. Used by the health check "driver" to abort runaway checks. Should also be used by the function performing actual checks where appropriate.
(health-checks-spec->description health-checks-spec)(make-handler path health-checks-spec)(require-signal-type signal expected-type)(reset-signal-timestamps!)(resolve-check signal-id health-checks-spec)(result->elapsed-response result)(result->status-response result)(status-signal? description)(touch! signal-id)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |